from typing import (
    Dict,
    ClassVar
)

from .request import RequestConnectionBase
from .parser import ParseKbu

__all__ = (
    'Kbu',
)


class Kbu(RequestConnectionBase):
    HOST: ClassVar[str] = 'http://www.bible.ac.kr'
    URIS: ClassVar[Dict[str, str]] = {
        'notice': HOST + '/bible_report/college_notice.aspx',
        'notice_page': HOST + '/bible_report/college_notice_view.aspx?seq='
    }

    async def get_notice(self, seq: str) -> Dict[str, str]:
        uri = f'{Kbu.URIS["notice_page"]}{seq}'
        req = await self.request.get(
            uri=uri,
            ssl=False,
        )
        html = await req.text()
        return ParseKbu.parse_notice_page(html)
